# VBO Media Export

**VBO Media Export** is a contrib Drupal module that integrates with the [Views Bulk Operations (VBO)](https://www.drupal.org/project/views_bulk_operations) module to allow users to download selected media entities as a ZIP archive. It supports bulk operations to export media from various media types with custom field configurations.

## Features

- Allows the bulk download of media entities as a ZIP file.
- Configurable to select media types and corresponding field machine names.
- Displays success or error messages for processed files.
- Provides a download link for the generated ZIP file.
- Handles failed file paths and provides clickable links to media entity pages for review.

## Requirements

- Drupal 8.x or higher.
- [Views Bulk Operations](https://www.drupal.org/project/views_bulk_operations) module installed and enabled.
- Appropriate permissions to access and manage media entities.

## Installation

1. Download and install the module:

    ```bash
    composer require drupal/vbo_media_export
    ```

2. Enable the module via Drush or the Drupal admin interface:

    ```bash
    drush en vbo_media_export
    ```

3. Ensure that the **Views Bulk Operations** module is installed and enabled.

4. Clear Drupal cache:

    ```bash
    drush cr
    ```

## Configuration

1. Navigate to **Structure** → **Views** → Create or edit a view displaying media entities.
2. Add the **Download selected media as ZIP** action to your view's bulk operations.
3. Configure the action settings:
   - **Select media types** you want to include in the exportable.
   - Provide **field machine names** for the corresponding media fields.
4. Save the view and use the bulk operation to export selected media.

## Usage

After the action is added to a view with media entities:

1. Use the bulk operations menu to select the "Download selected media as ZIP" action.
2. The module will gather file paths for the selected media entities, generate a ZIP file, and provide a download link.
3. In case of any failed file paths, a warning message will display, with links to the corresponding media entity pages for further investigation.

## Example Usage

Once the module is installed and configured, you can trigger the action via a view's bulk operation as follows:

1. Navigate to a view listing media items.
2. Select media items for export.
3. Use the bulk operation dropdown to choose **Download selected media as ZIP**.
4. Once processed, a link to download the ZIP archive will be presented.

### Success Message

Your download is ready: Download ZIP

### Failed Files Message

The following files could not be added to the ZIP file:

media entity: 1234 file: media-file.jpg

## Customization

### Configuring Media Fields

You can configure which media fields to export by specifying the field machine names for each media type. This is done via the preconfiguration form when setting up the action in the view.

### Validation of Field Machine Names

When setting the field machine name for a media type, the module will validate that the field exists for that media type. If the field does not exist, an error will be displayed.

## Development

If you wish to extend or modify the module, you can find the main class `VboMediaExportAction` located in the `src/Plugin/Action` directory. The class provides methods to handle file validation, batch processing, and ZIP file creation.

## Maintainers

- Mohammad Fayoumi - [Mohammad-Fayoumi](https://www.drupal.org/u/mohammad-fayoumi)

- Development sponsored by Vardot - [Vardot](https://www.drupal.org/vardot)

## License

This project is licensed under the [MIT License](LICENSE).
